=== modified file 'bzrlib/branch.py'
--- bzrlib/branch.py	2005-09-14 16:37:24 +0000
+++ bzrlib/branch.py	2005-09-18 21:37:03 +0000
@@ -890,6 +890,7 @@
     def lookup_revision(self, revision):
         """Return the revision identifier for a given revision information."""
         revno, info = self._get_revision_info(revision)
+        assert info is not None or revno == 0, (info, revno)
         return info
 
 

=== modified file 'bzrlib/merge.py'
--- bzrlib/merge.py	2005-09-15 21:32:56 +0000
+++ bzrlib/merge.py	2005-09-18 21:37:03 +0000
@@ -285,12 +285,9 @@
                 base_rev_id = None
             else:
                 base_rev_id = base_branch.lookup_revision(base_revision[1])
-            if base_rev_id is not None:
-                base_is_ancestor = is_ancestor(this_rev_id, base_rev_id, 
-                                               MultipleRevisionSources(this_branch, 
-                                                                       base_branch))
-            else:
-                base_is_ancestor = False
+            multi_source = MultipleRevisionSources(this_branch, base_branch)
+            base_is_ancestor = is_ancestor(this_rev_id, base_rev_id,
+                                           multi_source)
         if file_list is None:
             interesting_ids = None
         else:

=== modified file 'bzrlib/revision.py'
--- bzrlib/revision.py	2005-09-18 19:21:48 +0000
+++ bzrlib/revision.py	2005-09-18 21:37:03 +0000
@@ -106,7 +106,8 @@
     revisions_source is an object supporting a get_revision operation that
     behaves like Branch's.
     """
-
+    if candidate_id is None:
+        return True
     for ancestor_id, distance in iter_ancestors(revision_id, revision_source):
         if ancestor_id == candidate_id:
             return True

=== modified file 'bzrlib/selftest/testmerge.py'
--- bzrlib/selftest/testmerge.py	2005-09-14 16:35:46 +0000
+++ bzrlib/selftest/testmerge.py	2005-09-18 21:37:03 +0000
@@ -24,7 +24,14 @@
     def test_unrelated(self):
         br2 = self.test_nocommits()
         commit(br2, "blah")
-        merge, ['branch2', -1], [None, None]
         self.assertRaises(UnrelatedBranches, merge, ['branch2', -1], 
                           [None, None])
+        return br2
 
+    def test_pending_with_null(self):
+        """When base is forced to revno 0, pending_merges is set"""
+        br2 = self.test_unrelated()
+        br1 = Branch('.')
+        merge(['branch2', -1], ['branch2', 0])
+        self.assertEquals(len(br1.pending_merges()), 1)
+        return (br1, br2)

